 .. Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at

 ..   http://www.apache.org/licenses/LICENSE-2.0

 .. Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.


.. _supported_classes:openlineage:

Supported classes
===================

Below is a list of Operators and Hooks that support OpenLineage extraction, along with specific DB types that are compatible with the SQLExecuteQueryOperator.

.. important::

    While we strive to keep the list of supported classes current,
    please be aware that our updating process is automated and may not always capture everything accurately.
    Detecting hook level lineage is challenging so make sure to double check the information provided below.

.. tip::

  You can easily implement OpenLineage support for any operator. See :ref:`guides/developer:openlineage`.

.. airflow-providers-openlineage-supported-classes::
